@@ -5,8 +5,12 @@ import django.conf.global_settings as DEFAULT_SETTINGS
 # Thumbnail aliases determines default image sizes for easy-thumbnails
 THUMBNAIL_ALIASES = {
     '': {
-        'thumb':  {'size': (50, 50),   'autocrop': True, 'crop': 'smart', 'upscale': True},
-        't_80':   {'size': (80, 80),   'autocrop': True, 'crop': 'smart', 'upscale': True},
+        'thumb':     {'size': (50, 50),   'autocrop': True, 'crop': 'smart', 'upscale': True},
+        'one_col':   {'size': (60, 60),   'autocrop': True, 'crop': 'smart', 'upscale': True},
+        't_80':      {'size': (80, 80),   'autocrop': True, 'crop': 'smart', 'upscale': True},
+        'two_col':   {'size': (140, 140), 'autocrop': True,},
+        'two_col_c': {'size': (140, 140), 'autocrop': True, 'crop': 'smart', 'upscale': True},
+        
         't_180':  {'size': (180, 180), 'autocrop': True, 'crop': 'smart', 'upscale': True},
         't_180t': {'size': (180, 240), 'autocrop': True, 'crop': '0,-10', 'upscale': True},
         't_180u': {'size': (180, 240), 'autocrop': True},
